/**
 * A wrapper around a web worker that allows scheduling tasks for a given worker,
 * returning results asynchronously via a promise.
 *
 * The Worker is not constructed until a task is scheduled.
 *
 * @alias TaskProcessor
 * @constructor
 *
 * @param {String} workerPath The Url to the worker. This can either be an absolute path or relative to the Cesium Workers folder.
 * @param {Number} [maximumActiveTasks=5] The maximum number of active tasks.  Once exceeded,
 *                                        scheduleTask will not queue any more tasks, allowing
 *                                        work to be rescheduled in future frames.
 */
export declare class TaskProcessor {
    static _defaultWorkerModulePrefix: string;
    static _workerModulePrefix: string;
    static _canTransferArrayBuffer: boolean;
    private _workerPath;
    private _maximumActiveTasks;
    private _activeTasks;
    _deferreds: any;
    private _nextID;
    private _worker;
    constructor(workerPath: string, maximumActiveTasks?: number);
    scheduleTask(parameters: any, transferableObjects: any): undefined;
    isDestroyed(): boolean;
    /**
     * Destroys this object.  This will immediately terminate the Worker.
     * <br /><br />
     * Once an object is destroyed, it should not be used; calling any function other than
     * <code>isDestroyed</code> will result in a {@link DeveloperError} exception.
     */
    destroy(): void;
}
